@@ -1,11 +1,14 @@
 #ifndef GPS_H
 #define GPS_H
 
+#include <QObject>
+
+#ifdef Q_WS_MAEMO_5
+
 extern "C" {
 #include <location/location-gps-device.h>
 #include <location/location-gpsd-control.h>
 }
-#include <QObject>
 
 class GpsMaemo5 : public QObject {
     Q_OBJECT
@@ -43,4 +46,5 @@ private:
 
 void GpsMaemo5_changed(LocationGPSDevice *device, GpsMaemo5 *gps);
 
+#endif
 #endif // GPS_H
